MethodChannelFabAnalytics class

An implementation of FabAnalyticsPlatform that uses method channels.

Inheritance

Constructors

MethodChannelFabAnalytics()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
override
init(Config config) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
takeScreenshot({required BuildContext context, required Config? config}) → void
override
toString() → String
A string representation of this object.
inherited
trace({String? userId, required String fromScreen, required String toScreen, String? action, Map? params, Config? config}) → Future
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited