FabAnalyticsPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FabAnalyticsPlatform
Implementers

Constructors

FabAnalyticsPlatform()
Constructs a FabAnalyticsPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
init(Config config) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
takeScreenshot({required BuildContext context, required Config? config}) → void
toString() → String
A string representation of this object.
inherited
trace({String? userId, required String fromScreen, required String toScreen, String? action, Map? params, Config? config}) → Future

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ FabAnalyticsPlatform
The default instance of FabAnalyticsPlatform to use.
getter/setter pair