Fields class

Constructors

Fields({String? key, String? acl, String? bucket, String? xAmzAlgorithm, String? xAmzCredential, String? xAmzDate, String? policy, String? xAmzSignature})
Fields.fromJson(Map<String, dynamic> json)

Properties

acl ↔ String?
getter/setter pair
bucket ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
policy ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xAmzAlgorithm ↔ String?
getter/setter pair
xAmzCredential ↔ String?
getter/setter pair
xAmzDate ↔ String?
getter/setter pair
xAmzSignature ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited