Config class

Constructors

Config({required dynamic credentials, required dynamic packageInfo, required bool isDebugMode, GlobalKey<State<StatefulWidget>>? appKey})
Config.fromJson(Map<String, dynamic> json)
factory

Properties

appKey ↔ GlobalKey<State<StatefulWidget>>?
getter/setter pair
credentials ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDebugMode ↔ bool
getter/setter pair
packageInfo ↔ dynamic
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

token ↔ String?
getter/setter pair